==> flexible_tree_view-0.0.1.tar.gz: README.md <==
![](https://tva1.sinaimg.cn/large/008i3skNgy1gyuj1fzhu2j30qs0atq33.jpg)

## Features

- Expand / Collapse the tree nodes;
- Show lines of parent -> child nodes;
- High flexible to custom node widget

## Getting started

```yaml
dependencies:
    flexible_tree_view: ^0.0.1
```

## Screen Shot

![](https://tva1.sinaimg.cn/large/008i3skNgy1gyui2q97xmj312a0u0jsh.jpg)

![](https://tva1.sinaimg.cn/large/008i3skNgy1gyuilaokvjg30qo0f01j4.gif)

## Usage

```dart
import 'package:flexible_tree_view/flexible_tree_view.dart';

FlexibleTreeView<String>(
	nodes: [
		TreeNode<String>(
			data: 'Cities', 
			expanded: true, 
			children: [
				TreeNode<String>(data: 'Beijing'), 
				TreeNode<Strnig>(data: 'Shanghai'),
				TreeNode<String>(data: 'Tokyo'),
				TreeNode<String>(data: 'Paris')
			]
		)
	],
	nodeItemBuilder: (context, node) {
		return Padding(
			padding: const EdgeInsets.symmetric(vertical: 8),
			child: Row(
				children: [
				node.children.isNotEmpty
					? IconButton(
						iconSize: 12,
						splashRadius: 16,
						padding: EdgeInsets.zero,
						constraints:
							BoxConstraints.tight(Size(30, 30)),
						icon: Icon(node.expanded
							? Icons.remove
							: Icons.add),
						onPressed: () {
							node.expanded = !node.expanded;
						},
						)
					: const SizedBox(
						width: 12,
						),
				Text(
					node.data,
					style: TextStyle(
					fontSize: 12,
					color: Colors.black,
					),
					overflow: TextOverflow.ellipsis,
				)
				],
			));
	},
)
```

# License

See [LICENSE](LICENSE)

==> flexible_tree_view-0.0.2.tar.gz: README.md <==
![](https://tva1.sinaimg.cn/large/008i3skNgy1gyujo33a5sj30qs0atmxc.jpg)

## Features

- Expand / Collapse the tree nodes;
- Show lines of parent -> child nodes;
- High flexible to custom node widget

## Getting started

```yaml
dependencies:
    flexible_tree_view: ^0.0.2
```

## Screen Shot

![](https://tva1.sinaimg.cn/large/008i3skNgy1gyui2q97xmj312a0u0jsh.jpg)

![](https://tva1.sinaimg.cn/large/008i3skNgy1gyuilaokvjg30qo0f01j4.gif)

## Usage

```dart
import 'package:flexible_tree_view/flexible_tree_view.dart';

FlexibleTreeView<String>(
	nodes: [
		TreeNode<String>(
			data: 'Cities', 
			expanded: true, 
			children: [
				TreeNode<String>(data: 'Beijing'), 
				TreeNode<String>(data: 'Shanghai'),
				TreeNode<String>(data: 'Tokyo'),
				TreeNode<String>(data: 'Paris')
			]
		)
	],
	nodeItemBuilder: (context, node) {
		return Padding(
			padding: const EdgeInsets.symmetric(vertical: 8),
			child: Row(
				children: [
				node.hasNodes
					? IconButton(
						iconSize: 12,
						splashRadius: 16,
						padding: EdgeInsets.zero,
						constraints:
							BoxConstraints.tight(Size(30, 30)),
						icon: Icon(node.expanded
							? Icons.remove
							: Icons.add),
						onPressed: () {
							node.expanded = !node.expanded;
						},
						)
					: const SizedBox(
						width: 12,
						),
				Text(
					node.data,
					style: TextStyle(
					fontSize: 12,
					color: Colors.black,
					),
					overflow: TextOverflow.ellipsis,
				)
				],
			));
	},
)
```

# License

See [LICENSE](LICENSE)
